Structs
Constants
- MAX_
TIMEOUT_ MS - PostgreSQL stores
lock_timeoutandstatement_timeoutas signed 32-bit millisecond GUCs. Values above this limit are rejected by PostgreSQL.
Functions
- parse_
timeout_ ms - Parse PostgreSQL’s documented timeout syntax and normalize it to the integer millisecond representation used by its timeout GUCs.