pub fn analyze_chain(
config: Config,
files: &[(String, String)],
cache: DbCache,
) -> Result<AnalysisOutcome<ReportFinding>, AnalysisError>Expand description
Analyze an ordered migration chain with a fresh validated baseline.
pub fn analyze_chain(
config: Config,
files: &[(String, String)],
cache: DbCache,
) -> Result<AnalysisOutcome<ReportFinding>, AnalysisError>Analyze an ordered migration chain with a fresh validated baseline.