#[non_exhaustive]pub struct BaselineInspection {Show 13 fields
pub available: bool,
pub path: Option<String>,
pub format_version: Option<u32>,
pub encrypted: bool,
pub created_at_unix_secs: Option<u64>,
pub age_seconds: Option<u64>,
pub source_database: Option<String>,
pub schemas: Option<Vec<String>>,
pub coverage: BaselineCoverage,
pub search_path: Vec<String>,
pub postgresql_version_num: Option<u32>,
pub observed_settings: ObservedSettings,
pub contents: BaselineContents,
}Expand description
Redacted baseline inspection suitable for display or serialization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.available: boolWhether a synchronized baseline is present.
path: Option<String>Source cache path, when loaded from disk.
format_version: Option<u32>On-disk cache format version, when a cache is present.
encrypted: boolWhether the source cache was encrypted.
created_at_unix_secs: Option<u64>Baseline creation time as Unix seconds.
age_seconds: Option<u64>Age of the baseline in seconds, or None when its timestamp is absent
or lies in the future.
source_database: Option<String>Redacted source database name.
schemas: Option<Vec<String>>Explicit synchronized schema scope, when configured.
coverage: BaselineCoverageCatalog coverage captured by synchronization.
search_path: Vec<String>Effective PostgreSQL search path.
postgresql_version_num: Option<u32>PostgreSQL numeric server version.
observed_settings: ObservedSettingsTimeouts observed during synchronization.
contents: BaselineContentsRedacted object counts.