protect_cache_bytes

Function protect_cache_bytes 

pub fn protect_cache_bytes(
    cache_bytes: Vec<u8>,
    encryption_enabled: bool,
) -> Result<Vec<u8>>
Encrypts an encoded cache when cache encryption is enabled. The on-disk envelope includes only a format marker and random nonce; the authenticated ciphertext contains all cache metadata.