Config

Struct Config 

pub struct Config {
    pub tier1_threshold_rows: u64,
    pub tier2_threshold_rows: u64,
    pub stale_stats_days: u64,
    pub toast_width_threshold_bytes: i32,
    pub default_rows: u64,
    pub assume_pg_version: u32,
    pub disabled_rules: Vec<String>,
    pub rules: HashMap<String, RuleConfig>,
}

Fields

tier1_threshold_rows: u64tier2_threshold_rows: u64stale_stats_days: u64toast_width_threshold_bytes: i32default_rows: u64assume_pg_version: u32disabled_rules: Vec<String>rules: HashMap<String, RuleConfig>

Implementations

Source

impl Config

pub fn load_from_file(path: &Path) -> Self

pub fn is_rule_disabled(&self, rule_id: &str) -> bool

Checks if a rule is completely disabled

pub fn rule_tier1_threshold(&self, rule_id: &str) -> u64

Gets the Tier 1 threshold for a specific rule, falling back to the global default

pub fn rule_tier2_threshold(&self, rule_id: &str) -> u64

Gets the Tier 2 threshold for a specific rule, falling back to the global default