Module settings

Module settings 

Structs

ScopedSetting

Constants

MAX_TIMEOUT_MS
PostgreSQL stores lock_timeout and statement_timeout as signed 32-bit millisecond GUCs. Values above this limit are rejected by PostgreSQL.

Functions

parse_timeout_ms
Parse PostgreSQL’s documented timeout syntax and normalize it to the integer millisecond representation used by its timeout GUCs.